@@ -1,17 +1,25 @@
 from .core import (
     CRUDRouter,
-    MongoModel,
+    CRUDRouterService,
     MongoObjectId,
+    MongoModel,
+    DeletedModelOut,
     CRUDLookup,
+    CRUDEmbed,
 )
+from bson import ObjectId
 
 __all__ = [
-    "CRUDRouter",
-    "MongoModel",
+    "ObjectId",
     "MongoObjectId",
+    "MongoModel",
+    "DeletedModelOut",
+    "CRUDRouter",
+    "CRUDRouterService",
     "CRUDLookup",
+    "CRUDEmbed",
 ]
 
-__version__ = "0.0.5"
+__version__ = "0.1.3"
 __author__ = "Pierre DUVEAU"
 __credits__ = ["Pierre DUVEAU", "Adam Watkins"]
