@@ -1,5 +1,4 @@
-class CRUDEmbed():
-
+class CRUDEmbed:
     def __init__(self, model, embed_name) -> None:
         self.model = model
-        self.embed_name = embed_name
\ No newline at end of file
+        self.embed_name = embed_name
