@@ -1,4 +1,4 @@
-from .CRUDRouter import CRUDRouter
+from .CRUDRouter import CRUDRouter, CRUDRouterService
 from .embed.CRUDEmbedRouter import CRUDEmbedRouter
 from .lookup.CRUDLookupRouter import CRUDLookupRouter
 
@@ -6,5 +6,5 @@ __all__ = [
     "CRUDRouter",
     "CRUDEmbedRouter",
     "CRUDLookupRouter",
-
+    "CRUDRouterService"
 ]
